@@ -3,12 +3,6 @@ from logging import Logger
 from typing import Generic
 from maleo.logging.enums import Level
 from maleo.mixins.general import Success, SuccessT
-from maleo.security.authentication import (
-    OptionalAnyAuthenticationT,
-    AuthenticationMixin,
-)
-from maleo.security.authorization import OptionalAuthorizationT, AuthorizationMixin
-from maleo.security.impersonation import OptionalImpersonation, ImpersonationMixin
 from maleo.types.boolean import OptionalBoolean
 from maleo.types.dict import (
     OptionalStringToStringDict,
@@ -16,12 +10,22 @@ from maleo.types.dict import (
     StringToStringDict,
 )
 from maleo.utils.merger import merge_dicts
-from ..contexts.request import OptionalRequestContextT, RequestContextMixin
-from ..contexts.response import OptionalResponseContextT, ResponseContextMixin
-from ..contexts.service import ServiceContextMixin
+from ..application import ApplicationContextMixin
+from ..connection import OptionalConnectionContextT, ConnectionContextMixin
 from ..error import OptionalAnyErrorT, ErrorMixin
 from ..resource import OptionalResourceT, ResourceMixin
-from ..response import ResponseT, ResponseMixin
+from ..response import (
+    OptionalResponseContextT,
+    ResponseContextMixin,
+    ResponseT,
+    ResponseMixin,
+)
+from ..security.authentication import (
+    OptionalAnyAuthenticationT,
+    AuthenticationMixin,
+)
+from ..security.authorization import OptionalAuthorizationT, AuthorizationMixin
+from ..security.impersonation import OptionalImpersonation, ImpersonationMixin
 from .action import (
     ActionMixin,
     ActionT,
@@ -36,7 +40,7 @@ class BaseOperation(
     ImpersonationMixin[OptionalImpersonation],
     AuthorizationMixin[OptionalAuthorizationT],
     AuthenticationMixin[OptionalAnyAuthenticationT],
-    RequestContextMixin[OptionalRequestContextT],
+    ConnectionContextMixin[OptionalConnectionContextT],
     ErrorMixin[OptionalAnyErrorT],
     Success[SuccessT],
     Summary,
@@ -46,13 +50,13 @@ class BaseOperation(
     ContextMixin,
     OperationType,
     Id,
-    ServiceContextMixin,
+    ApplicationContextMixin,
     Generic[
         ActionT,
         OptionalResourceT,
         SuccessT,
         OptionalAnyErrorT,
-        OptionalRequestContextT,
+        OptionalConnectionContextT,
         OptionalAnyAuthenticationT,
         OptionalAuthorizationT,
         ResponseT,
@@ -70,10 +74,10 @@ class BaseOperation(
 
         message += f"{success_information} - "
 
-        if self.request_context is not None:
+        if self.connection_context is not None:
             message += (
-                f"{self.request_context.method} {self.request_context.url} - "
-                f"IP: {self.request_context.ip_address} - "
+                f"{self.connection_context.method} {self.connection_context.url} - "
+                f"IP: {self.connection_context.ip_address} - "
             )
 
         if self.authentication is None:
@@ -100,16 +104,17 @@ class BaseOperation(
     @property
     def labels(self) -> StringToStringDict:
         labels = {
-            "service": self.service_context.key,
-            "environment": self.service_context.environment,
+            "service": self.application_context.key,
+            "environment": self.application_context.environment,
             "operation_id": str(self.id),
             "operation_type": self.type,
             "success": "true" if self.success else "false",
         }
 
-        if self.request_context is not None:
-            labels["method"] = self.request_context.method
-            labels["url"] = self.request_context.url
+        if self.connection_context is not None:
+            if self.connection_context.method is not None:
+                labels["method"] = self.connection_context.method
+            labels["url"] = self.connection_context.url
         if self.response_context is not None:
             labels["status_code"] = str(self.response_context.status_code)
 
