@@ -1,6 +1,6 @@
 from fastapi import status, HTTPException, Request
 from uuid import UUID, uuid4
-from maleo.enums.request import Header
+from maleo.enums.connection import Header
 from .enums import IdSource
 
 
