@@ -1,17 +1,17 @@
 from datetime import datetime, timezone
 from pydantic import BaseModel, Field, model_validator
-from typing import Self
+from typing import Annotated, Optional, Self
 from uuid import UUID
 from .enums import OperationType as OperationTypeEnum
 from maleo.mixins.timestamp import ExecutionTimestamp, CompletionTimestamp, Duration
 
 
 class Id(BaseModel):
-    id: UUID = Field(..., description="Operation's id")
+    id: Annotated[UUID, Field(..., description="Operation's id")]
 
 
 class OperationType(BaseModel):
-    type: OperationTypeEnum = Field(..., description="Operation's type")
+    type: Annotated[OperationTypeEnum, Field(..., description="Operation's type")]
 
 
 class Timestamp(
@@ -19,7 +19,7 @@ class Timestamp(
     CompletionTimestamp[datetime],
     ExecutionTimestamp[datetime],
 ):
-    duration: float = Field(0.0, ge=0.0, description="Duration")
+    duration: Annotated[float, Field(0.0, ge=0.0, description="Duration")] = 0.0
 
     @model_validator(mode="after")
     def calculate_duration(self) -> Self:
@@ -41,9 +41,12 @@ class Timestamp(
         )
 
 
+OptionalTimestamp = Optional[Timestamp]
+
+
 class TimestampMixin(BaseModel):
-    timestamp: Timestamp = Field(..., description="Operation's timestamp")
+    timestamp: Annotated[Timestamp, Field(..., description="Operation's timestamp")]
 
 
 class Summary(BaseModel):
-    summary: str = Field(..., description="Operation's summary")
+    summary: Annotated[str, Field(..., description="Operation's summary")]
