@@ -2,19 +2,19 @@ from copy import deepcopy
 from typing import Any, Generic, Literal, Optional, Type, Union, overload
 from uuid import UUID
 from maleo.mixins.general import SuccessT
-from maleo.security.authentication import OptionalAnyAuthenticationT
-from maleo.security.authorization import OptionalAuthorizationT
-from maleo.security.impersonation import OptionalImpersonation
-from ..contexts.request import RequestContext
-from ..contexts.response import ResponseContext
-from ..contexts.service import ServiceContext
+from ..application import ApplicationContext
+from ..connection import ConnectionContext
 from ..error import OptionalAnyErrorT, AnyErrorT
 from ..pagination import OptionalAnyPagination
 from ..response import (
+    ResponseContext,
     ResponseT,
     ErrorResponseT,
     AnyDataResponse,
 )
+from ..security.authentication import OptionalAnyAuthenticationT
+from ..security.authorization import OptionalAuthorizationT
+from ..security.impersonation import OptionalImpersonation
 from .action.resource import (
     AnyResourceOperationActionT,
     CreateResourceOperationAction,
@@ -44,7 +44,7 @@ class RequestOperation(
         None,
         SuccessT,
         OptionalAnyErrorT,
-        RequestContext,
+        ConnectionContext,
         OptionalAnyAuthenticationT,
         OptionalAuthorizationT,
         ResponseT,
@@ -504,13 +504,13 @@ class FailedFactory(
         cls,
         action: CreateResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -525,13 +525,13 @@ class FailedFactory(
         cls,
         action: ReadResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -546,13 +546,13 @@ class FailedFactory(
         cls,
         action: UpdateResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -567,13 +567,13 @@ class FailedFactory(
         cls,
         action: DeleteResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -588,13 +588,13 @@ class FailedFactory(
         cls,
         action: AnyResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -633,13 +633,13 @@ class FailedFactory(
         *,
         type_: Literal[ResourceOperationType.CREATE],
         create_type: Optional[ResourceOperationCreateType] = ...,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -654,13 +654,13 @@ class FailedFactory(
         cls,
         *,
         type_: Literal[ResourceOperationType.READ],
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -678,13 +678,13 @@ class FailedFactory(
         update_type: Optional[ResourceOperationUpdateType] = ...,
         data_update_type: Optional[ResourceOperationDataUpdateType] = ...,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = ...,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -699,13 +699,13 @@ class FailedFactory(
         cls,
         *,
         type_: Literal[ResourceOperationType.DELETE],
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -724,13 +724,13 @@ class FailedFactory(
         update_type: Optional[ResourceOperationUpdateType] = None,
         data_update_type: Optional[ResourceOperationDataUpdateType] = None,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -772,13 +772,13 @@ class FailedFactory(
         update_type: Optional[ResourceOperationUpdateType] = None,
         data_update_type: Optional[ResourceOperationDataUpdateType] = None,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -816,13 +816,13 @@ class FailedFactory(
             raise ValueError("Only either 'action' or 'type' must be given")
 
         common_kwargs = {
-            "service_context": service_context,
+            "application_context": application_context,
             "id": id,
             "context": context,
             "timestamp": timestamp,
             "summary": summary,
             "error": error,
-            "request_context": request_context,
+            "connection_context": connection_context,
             "authentication": authentication,
             "authorization": authorization,
             "impersonation": impersonation,
@@ -1048,12 +1048,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         cls,
         action: CreateResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1068,12 +1068,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         cls,
         action: ReadResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1088,12 +1088,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         cls,
         action: UpdateResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1108,12 +1108,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         cls,
         action: DeleteResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1128,12 +1128,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         cls,
         action: AnyResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1160,12 +1160,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         *,
         type_: Literal[ResourceOperationType.CREATE],
         create_type: Optional[ResourceOperationCreateType] = ...,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1180,12 +1180,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         cls,
         *,
         type_: Literal[ResourceOperationType.READ],
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1203,12 +1203,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         update_type: Optional[ResourceOperationUpdateType] = ...,
         data_update_type: Optional[ResourceOperationDataUpdateType] = ...,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = ...,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1223,12 +1223,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         cls,
         *,
         type_: Literal[ResourceOperationType.DELETE],
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1247,12 +1247,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         update_type: Optional[ResourceOperationUpdateType] = None,
         data_update_type: Optional[ResourceOperationDataUpdateType] = None,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1282,12 +1282,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
         update_type: Optional[ResourceOperationUpdateType] = None,
         data_update_type: Optional[ResourceOperationDataUpdateType] = None,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         timestamp: Timestamp,
         summary: str,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -1313,12 +1313,12 @@ class SuccessfulFactory(Generic[OptionalAnyAuthenticationT, OptionalAuthorizatio
             raise ValueError("Only either 'action' or 'type' must be given")
 
         common_kwargs = {
-            "service_context": service_context,
+            "application_context": application_context,
             "id": id,
             "context": context,
             "timestamp": timestamp,
             "summary": summary,
-            "request_context": request_context,
+            "connection_context": connection_context,
             "authentication": authentication,
             "authorization": authorization,
             "impersonation": impersonation,
