@@ -2,11 +2,8 @@ from copy import deepcopy
 from typing import Generic, Literal, Optional, Type, Union, overload
 from uuid import UUID
 from maleo.mixins.general import SuccessT
-from maleo.security.authentication import OptionalAnyAuthenticationT
-from maleo.security.authorization import OptionalAuthorizationT
-from maleo.security.impersonation import OptionalImpersonation
-from ..contexts.request import OptionalRequestContext
-from ..contexts.service import ServiceContext
+from ..application import ApplicationContext
+from ..connection import OptionalConnectionContext
 from ..data import ModelDataT
 from ..error import OptionalAnyErrorT, AnyErrorT
 from ..metadata import ModelMetadataT
@@ -26,6 +23,9 @@ from ..response import (
     UpdateMultipleDataResponse,
     DeleteMultipleDataResponse,
 )
+from ..security.authentication import OptionalAnyAuthenticationT
+from ..security.authorization import OptionalAuthorizationT
+from ..security.impersonation import OptionalImpersonation
 from .action.resource import (
     AnyResourceOperationActionT,
     CreateResourceOperationAction,
@@ -55,7 +55,7 @@ class ResourceOperation(
         Resource,
         SuccessT,
         OptionalAnyErrorT,
-        OptionalRequestContext,
+        OptionalConnectionContext,
         OptionalAnyAuthenticationT,
         OptionalAuthorizationT,
         ResponseT,
@@ -615,14 +615,14 @@ class FailedFactory(
         cls,
         action: CreateResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -636,14 +636,14 @@ class FailedFactory(
         cls,
         action: ReadResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -657,14 +657,14 @@ class FailedFactory(
         cls,
         action: UpdateResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -678,14 +678,14 @@ class FailedFactory(
         cls,
         action: DeleteResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -699,14 +699,14 @@ class FailedFactory(
         cls,
         action: AnyResourceOperationAction,
         *,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -744,14 +744,14 @@ class FailedFactory(
         *,
         type_: Literal[ResourceOperationType.CREATE],
         create_type: Optional[ResourceOperationCreateType] = ...,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -765,14 +765,14 @@ class FailedFactory(
         cls,
         *,
         type_: Literal[ResourceOperationType.READ],
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -789,14 +789,14 @@ class FailedFactory(
         update_type: Optional[ResourceOperationUpdateType] = ...,
         data_update_type: Optional[ResourceOperationDataUpdateType] = ...,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = ...,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -810,14 +810,14 @@ class FailedFactory(
         cls,
         *,
         type_: Literal[ResourceOperationType.DELETE],
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -835,14 +835,14 @@ class FailedFactory(
         update_type: Optional[ResourceOperationUpdateType] = None,
         data_update_type: Optional[ResourceOperationDataUpdateType] = None,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -883,14 +883,14 @@ class FailedFactory(
         update_type: Optional[ResourceOperationUpdateType] = None,
         data_update_type: Optional[ResourceOperationDataUpdateType] = None,
         status_update_type: Optional[ResourceOperationStatusUpdateType] = None,
-        service_context: ServiceContext,
+        application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
         resource: Resource,
         timestamp: Timestamp,
         summary: str,
         error: AnyErrorT,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT,
         authorization: OptionalAuthorizationT,
         impersonation: OptionalImpersonation = None,
@@ -927,14 +927,14 @@ class FailedFactory(
             raise ValueError("Only either 'action' or 'type' must be given")
 
         common_kwargs = {
-            "service_context": service_context,
+            "application_context": application_context,
             "id": id,
             "context": context,
             "resource": resource,
             "timestamp": timestamp,
             "summary": summary,
             "error": error,
-            "request_context": request_context,
+            "connection_context": connection_context,
             "authentication": authentication,
             "authorization": authorization,
             "impersonation": impersonation,
