@@ -1,13 +1,13 @@
 from typing import Generic, Literal
 from maleo.mixins.general import SuccessT
-from maleo.security.authentication import OptionalAnyAuthenticationT
-from maleo.security.authorization import OptionalAuthorizationT
-from ..contexts.request import OptionalRequestContext
+from ..connection import OptionalConnectionContext
 from ..error import (
     OptionalAnyErrorT,
     AnyErrorT,
 )
 from ..response import ResponseT, ErrorResponseT, SuccessResponseT
+from ..security.authentication import OptionalAnyAuthenticationT
+from ..security.authorization import OptionalAuthorizationT
 from .action.system import SystemOperationAction
 from .base import BaseOperation
 from .enums import OperationType
@@ -19,7 +19,7 @@ class SystemOperation(
         None,
         SuccessT,
         OptionalAnyErrorT,
-        OptionalRequestContext,
+        OptionalConnectionContext,
         OptionalAnyAuthenticationT,
         OptionalAuthorizationT,
         ResponseT,
