@@ -1,11 +1,13 @@
 from pydantic import BaseModel, Field
 from typing import (
+    Annotated,
     Any,
     Dict,
     Generic,
     List,
     Literal,
     Optional,
+    Tuple,
     Type,
     TypeVar,
     Union,
@@ -69,6 +71,28 @@ from .success.descriptor import (
 from .success.enums import Code as SuccessCode
 
 
+class ResponseContext(BaseModel):
+    status_code: Annotated[int, Field(..., description="Status code")]
+    media_type: Annotated[
+        OptionalString, Field(None, description="Media type (Optional)")
+    ] = None
+    headers: Annotated[
+        Optional[List[Tuple[str, str]]], Field(None, description="Response's headers")
+    ] = None
+
+
+OptionalResponseContext = Optional[ResponseContext]
+OptionalResponseContextT = TypeVar(
+    "OptionalResponseContextT", bound=Optional[OptionalResponseContext]
+)
+
+
+class ResponseContextMixin(BaseModel, Generic[OptionalResponseContextT]):
+    response_context: OptionalResponseContextT = Field(
+        ..., description="Response's context"
+    )
+
+
 class Response(
     Payload[AnyDataT, OptionalPaginationT, AnyMetadataT],
     Descriptor[CodeT],
